# gtfs2series: Transform GTFS Realtime data into multivariate time series

## Description

This is an utility tool to retrieve and transform GTFS Schedule and Realtime data into multivariate time series, which is better suited for data analysis in several platforms.

## GTFS

### GTFS Schedule

All *static* information about the transit service is stored into the GTFS Schedule files, including agency, route, 

### GTFS Realtime

This and that.
